@@ -3,7 +3,7 @@ package Color::RGB::Util;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-01-19'; # DATE
 our $DIST = 'Color-RGB-Util'; # DIST
-our $VERSION = '0.602'; # VERSION
+our $VERSION = '0.603'; # VERSION
 
 use 5.010001;
 use strict;
@@ -524,7 +524,7 @@ Color::RGB::Util - Utilities related to RGB colors
 
 =head1 VERSION
 
-This document describes version 0.602 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2021-01-19.
+This document describes version 0.603 of Color::RGB::Util (from Perl distribution Color-RGB-Util), released on 2021-01-19.
 
 =head1 SYNOPSIS
 
@@ -704,8 +704,9 @@ Usage:
 
  my @rgbs = rand_rgb_colors([ \%opts ], $num=1);
 
-Produce C<$num> random RGB colors, with some options. Will make reasonable
-attempt to make the colors different from one another.
+Produce C<$num> random RGB colors, with some options. It does not (yet) create a
+palette of optimally distinct colors, but will make reasonable attempt to make
+the colors different from one another.
 
 Known options:
 
